Implementation details
======================

.. rubric:: Modules

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:

   ~flory.mcmp._finder_impl

The module here is the implementation details for the core algorithm of
:class:`~flory.mcmp.finder`, which may not be stable and are not intended for usual usage.
See :ref:`API Reference` for the public interface.